@@ -3,6 +3,8 @@ from .oss_pipeline import OSSPipeline
 from .mongo_pipeline import MongoPipeline
 from .item_check_pipeline import ItemCheckPipeline
 from .filter_pipeline import FilterCheckPipeline, FilterSavePipeline
+from .request import RequestPipeline
+
 # from .redis_duplicate_pipeline import RedisDuplicatesPipeline
 
 ITEM_CHECK_PIPELINE = 'scrapy_nc.pipelines.ItemCheckPipeline'
@@ -11,6 +13,7 @@ OSS_PIPELINE = 'scrapy_nc.pipelines.OSSPipeline'
 AMQP_PIPELINE = 'scrapy_nc.pipelines.AMQPPipeline'
 MONGO_PIPELINE = 'scrapy_nc.pipelines.MongoPipeline'
 FILTER_SAVE_PIPELINE = 'scrapy_nc.pipelines.FilterSavePipeline'
+REQUEST_PIPELINE = 'scrapy_nc.pipelines.RequestPipeline'
 
 DEFAULT_PIPELINES = {
     ITEM_CHECK_PIPELINE: 500,
@@ -19,4 +22,5 @@ DEFAULT_PIPELINES = {
     AMQP_PIPELINE: 650,
     MONGO_PIPELINE: 700,
     FILTER_SAVE_PIPELINE: 750,
+    REQUEST_PIPELINE: 760,
 }
